aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--build.xml15
-rw-r--r--lib/felix.client.run.properties1
-rw-r--r--src/net/java/sip/communicator/impl/hid/hid.manifest.mf4
-rw-r--r--src/net/java/sip/communicator/service/customavatar/CustomAvatarService.java4
-rw-r--r--src/net/java/sip/communicator/service/customavatar/customavatar.manifest.mf6
-rw-r--r--src/net/java/sip/communicator/service/protocol/protocol.provider.manifest.mf1
6 files changed, 21 insertions, 10 deletions
diff --git a/build.xml b/build.xml
index a9dc451..27b7b93 100644
--- a/build.xml
+++ b/build.xml
@@ -948,7 +948,7 @@
bundle-contactsource,bundle-plugin-reconnect,bundle-plugin-securityconfig,
bundle-plugin-advancedconfig,
bundle-credentialsstorage,bundle-credentialsstorage-slick,
- bundle-plugin-nimbuzzavatar,
+ bundle-plugin-nimbuzzavatar,bundle-custom-avatar,
bundle-replacement,bundle-youtube,bundle-dailymotion,bundle-smiley,
bundle-vimeo,bundle-vbox7,bundle-metacafe,bundle-flickr,bundle-hulu,
bundle-twitpic,bundle-directimage,bundle-bliptv,bundle-viddler,
@@ -1193,8 +1193,6 @@
<target name="bundle-hid">
<jar compress="false" destfile="${bundles.dest}/hid.jar"
manifest="${src}/net/java/sip/communicator/impl/hid/hid.manifest.mf">
- <zipfileset dir="${dest}/net/java/sip/communicator/service/hid"
- prefix="net/java/sip/communicator/service/hid"/>
<zipfileset dir="${dest}/net/java/sip/communicator/impl/hid"
prefix="net/java/sip/communicator/impl/hid" />
</jar>
@@ -1343,8 +1341,6 @@ javax.swing.event, javax.swing.border"/>
<!-- Creates a bundle containing the protocol provider interfaces.-->
<jar compress="false" destfile="${bundles.dest}/protocol.jar"
manifest="${src}/net/java/sip/communicator/service/protocol/protocol.provider.manifest.mf">
- <zipfileset dir="${dest}/net/java/sip/communicator/service/customavatar"
- prefix="net/java/sip/communicator/service/customavatar" />
<zipfileset dir="${dest}/net/java/sip/communicator/service/protocol"
prefix="net/java/sip/communicator/service/protocol"/>
<zipfileset dir="${resources}/images"
@@ -2489,6 +2485,15 @@ javax.swing.event, javax.swing.border"/>
</jar>
</target>
+ <!-- BUNDLE-CUSTOM-AVATAR -->
+ <target name="bundle-custom-avatar">
+ <jar compress="false" destfile="${bundles.dest}/customavatar-service.jar"
+ manifest="${src}/net/java/sip/communicator/service/customavatar/customavatar.manifest.mf">
+ <zipfileset dir="${dest}/net/java/sip/communicator/service/customavatar"
+ prefix="net/java/sip/communicator/service/customavatar" />
+ </jar>
+ </target>
+
<!-- BUNDLE-REPLACEMENT -->
<target name="bundle-replacement">
<!-- Creates a bundle containing the replacement service.-->
diff --git a/lib/felix.client.run.properties b/lib/felix.client.run.properties
index 13c74d6..e76e846 100644
--- a/lib/felix.client.run.properties
+++ b/lib/felix.client.run.properties
@@ -177,6 +177,7 @@ felix.auto.start.67= \
reference:file:sc-bundles/replacement-directimage.jar \
reference:file:sc-bundles/replacement-bliptv.jar \
reference:file:sc-bundles/replacement-viddler.jar \
+ reference:file:sc-bundles/customavatar-service.jar \
reference:file:sc-bundles/plugin-nimbuzzavatars.jar \
reference:file:sc-bundles/chatconfig.jar \
reference:file:sc-bundles/addrbook.jar \
diff --git a/src/net/java/sip/communicator/impl/hid/hid.manifest.mf b/src/net/java/sip/communicator/impl/hid/hid.manifest.mf
index a4db319..17e50f2 100644
--- a/src/net/java/sip/communicator/impl/hid/hid.manifest.mf
+++ b/src/net/java/sip/communicator/impl/hid/hid.manifest.mf
@@ -6,5 +6,5 @@ Bundle-Version: 0.0.1
System-Bundle: yes
Import-Package: org.osgi.framework,
org.jitsi.util,
- net.java.sip.communicator.util
-Export-Package: net.java.sip.communicator.service.hid
+ net.java.sip.communicator.util,
+ net.java.sip.communicator.service.hid
diff --git a/src/net/java/sip/communicator/service/customavatar/customavatar.manifest.mf b/src/net/java/sip/communicator/service/customavatar/customavatar.manifest.mf
new file mode 100644
index 0000000..0d39921
--- /dev/null
+++ b/src/net/java/sip/communicator/service/customavatar/customavatar.manifest.mf
@@ -0,0 +1,6 @@
+Bundle-Name: Custom Avatar Service
+Bundle-Description: A bundle that offers custom avatar retrieving.
+Bundle-Vendor: jitsi.org
+Bundle-Version: 0.0.1
+System-Bundle: yes
+Export-Package: net.java.sip.communicator.service.customavatar
diff --git a/src/net/java/sip/communicator/service/protocol/protocol.provider.manifest.mf b/src/net/java/sip/communicator/service/protocol/protocol.provider.manifest.mf
index 42b53eb..ba437d8 100644
--- a/src/net/java/sip/communicator/service/protocol/protocol.provider.manifest.mf
+++ b/src/net/java/sip/communicator/service/protocol/protocol.provider.manifest.mf
@@ -16,7 +16,6 @@ Import-Package: net.java.sip.communicator.service.credentialsstorage,
org.osgi.framework
Export-Package: net.java.sip.communicator.service.protocol,
net.java.sip.communicator.service.protocol.aimconstants,
- net.java.sip.communicator.service.customavatar,
net.java.sip.communicator.service.protocol.event,
net.java.sip.communicator.service.protocol.globalstatus,
net.java.sip.communicator.service.protocol.icqconstants,
diff --git a/src/net/java/sip/communicator/service/customavatar/CustomAvatarService.java b/src/net/java/sip/communicator/service/customavatar/CustomAvatarService.java
index ab706ae..022d115 100644
--- a/src/net/java/sip/communicator/service/customavatar/CustomAvatarService.java
+++ b/src/net/java/sip/communicator/service/customavatar/CustomAvatarService.java
@@ -17,8 +17,8 @@ public interface CustomAvatarService
{
/**
* Returns the avatar bytes for the given contact address.
* @param address the address to search for its avatar.
* @return image bytes.
*/
- public byte[] getAvatar(String address);
+ public byte[] getAvatar(String contactAddress);
}
@@ -17,8 +17,8 @@ public interface CustomAvatarService
/**
* Returns the avatar bytes for the given contact address.
- * @param address the address to search for its avatar.
+ * @param contactAddress the address of a contact to search for its avatar.
* @return image bytes.
*/